Taika
=====

.. image:: https://img.shields.io/pypi/v/taika.svg
    :target: https://pypi.python.org/pypi/taika

.. image:: https://readthedocs.org/projects/taika/badge/?version=latest
    :target: https://taika.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://gitlab.com/hectormartinez/taika/badges/master/pipeline.svg
    :target: https://gitlab.com/hectormartinez/taika/commits/master
    :alt: Pipeline Status


Another Static Site Generator


* Free software: MIT license
* Documentation: https://taika.readthedocs.io.


Features
--------

* INI configuration
* Simple
* Extensible
* Documents JSON representated

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
